package ru.yandex.direct.web.entity.smsauth.validation;

import ru.yandex.direct.i18n.I18NBundle;
import ru.yandex.direct.i18n.Translatable;
import ru.yandex.direct.i18n.bundle.MessageFormatStub;
import ru.yandex.direct.i18n.bundle.TranslationBundle;

public interface SmsAuthDefectTranslations extends TranslationBundle {

    SmsAuthDefectTranslations INSTANCE = I18NBundle.implement(SmsAuthDefectTranslations.class);

    @MessageFormatStub("Ошибка аутентификации. Повторите действие через несколько секунд")
    Translatable sessionAlreadyLocked();

    @MessageFormatStub("Выбран телефон, не являющийся основным в Яндекс.Паспорте")
    Translatable incorrectUserPhone();

    @MessageFormatStub("Превышено ограничение на количество отправляемых SMS. Попробуйте повторить запрос позднее")
    Translatable smsDailyLimitExceeded();

    @MessageFormatStub("Ошибка аутентификации. Попробуйте повторно запросить SMS")
    Translatable smsNotSent();

    @MessageFormatStub("Превышено ограничение на количество попыток ввода пароля")
    Translatable noRetriesLeft();

    @MessageFormatStub("Неверный пароль")
    Translatable incorrectPassword();
}
